@@ -1,7 +1,7 @@
 import logging
 import time
 from datetime import datetime
-from ...models.chargerstates import CHARGERSTATES
+from ...models.chargecontroller_states import ChargeControllerStates
 from abc import abstractmethod
 from typing import List, Dict
 
@@ -11,7 +11,7 @@ _LOGGER = logging.getLogger(__name__)
 class ChargeControllerBase:  
     def __init__(
         self,
-        charger_state_translation:Dict[CHARGERSTATES,List[str]],
+        charger_state_translation:Dict[ChargeControllerStates,List[str]],
         non_hours:List[int] = [],
         timeout:int = 300
     ):
@@ -45,17 +45,17 @@ class ChargeControllerBase:
             ret = self._get_status_outlet()
         else:
             ret = self._get_status()
-        if ret == CHARGERSTATES.Error:
+        if ret == ChargeControllerStates.Error:
             msg = f"Chargecontroller returned faulty state. Charger reported {self._hub.chargerobject.value.lower()} as state."
             _LOGGER.error(msg)
         return ret.name
 
     @property
     @abstractmethod
-    def charger_state(self) -> CHARGERSTATES:
+    def charger_state(self) -> ChargeControllerStates:
         """
         Check if you are below the starting threshold of charger
-        :return: returns enum CHARGERSTATES
+        :return: returns enum ChargeControllerStates
         """
         pass
 
@@ -96,37 +96,37 @@ class ChargeControllerBase:
         pass
 
     @abstractmethod
-    def _get_status_charging(self) -> CHARGERSTATES:
+    def _get_status_charging(self) -> ChargeControllerStates:
         """
         
-        :return: returns enum CHARGERSTATES
+        :return: returns enum ChargeControllerStates
         """
         pass
 
     @abstractmethod
-    def _get_status_connected(self) -> CHARGERSTATES:
+    def _get_status_connected(self) -> ChargeControllerStates:
         """
         
-        :return: returns enum CHARGERSTATES
+        :return: returns enum ChargeControllerStates
         """
         pass
 
     def _get_status_outlet(self):
-        ret = CHARGERSTATES.Error
+        ret = ChargeControllerStates.Error
         update_timer = False
         free_charge = self._hub.locale.data.free_charge(self._hub.locale.data)
 
         if self._hub.charger_enabled.value is False:
             update_timer = True
-            ret = CHARGERSTATES.Disabled
+            ret = ChargeControllerStates.Disabled
         elif self._hub.charger_done.value is True:
-            ret = CHARGERSTATES.Done
+            ret = ChargeControllerStates.Done
         elif datetime.now().hour in self._hub.non_hours and free_charge is False and self._hub.timer.is_override is False:
             update_timer = True
-            ret = CHARGERSTATES.Stop
+            ret = ChargeControllerStates.Stop
         elif self._hub.chargertype.charger.entities.powerswitch == "on" and self._hub.chargertype.charger.entities.powermeter < 1:
             ret = self._get_status_connected()
-            update_timer = (ret == CHARGERSTATES.Stop)
+            update_timer = (ret == ChargeControllerStates.Stop)
         else:
             ret = self._get_status_charging()
             update_timer = True
@@ -136,31 +136,31 @@ class ChargeControllerBase:
         return ret
 
     def _get_status(self):
-        ret = CHARGERSTATES.Error
+        ret = ChargeControllerStates.Error
         update_timer = False
         charger_state = self._hub.chargerobject.value.lower()
         free_charge = self._hub.locale.data.free_charge(self._hub.locale.data)
 
         if self._hub.charger_enabled.value is False:
             update_timer = True
-            ret = CHARGERSTATES.Disabled
-        elif charger_state in self._hub.chargertype.charger.chargerstates[CHARGERSTATES.Done]:
+            ret = ChargeControllerStates.Disabled
+        elif charger_state in self._hub.chargertype.charger.chargerstates[ChargeControllerStates.Done]:
             self._hub.charger_done.value = True
-            ret = CHARGERSTATES.Done
-        elif charger_state in self._hub.chargertype.charger.chargerstates[CHARGERSTATES.Idle]:
+            ret = ChargeControllerStates.Done
+        elif charger_state in self._hub.chargertype.charger.chargerstates[ChargeControllerStates.Idle]:
             update_timer = True
-            ret = CHARGERSTATES.Idle
+            ret = ChargeControllerStates.Idle
             if self._hub.charger_done.value is True:
                 self._hub.charger_done.value = False
-        elif charger_state not in self._hub.chargertype.charger.chargerstates[CHARGERSTATES.Idle] and self._hub.charger_done.value is True:
-            ret = CHARGERSTATES.Done
+        elif charger_state not in self._hub.chargertype.charger.chargerstates[ChargeControllerStates.Idle] and self._hub.charger_done.value is True:
+            ret = ChargeControllerStates.Done
         elif datetime.now().hour in self._hub.non_hours and free_charge is False and self._hub.timer.is_override is False:
             update_timer = True
-            ret = CHARGERSTATES.Stop
-        elif charger_state in self._hub.chargertype.charger.chargerstates[CHARGERSTATES.Connected]:
+            ret = ChargeControllerStates.Stop
+        elif charger_state in self._hub.chargertype.charger.chargerstates[ChargeControllerStates.Connected]:
             ret = self._get_status_connected(charger_state)
-            update_timer = (ret == CHARGERSTATES.Stop)
-        elif charger_state in self._hub.chargertype.charger.chargerstates[CHARGERSTATES.Charging]:
+            update_timer = (ret == ChargeControllerStates.Stop)
+        elif charger_state in self._hub.chargertype.charger.chargerstates[ChargeControllerStates.Charging]:
             ret = self._get_status_charging()
             update_timer = True
 
@@ -169,8 +169,8 @@ class ChargeControllerBase:
         return ret
 
     def _is_done(self, charger_state) -> bool:
-        if len(self._hub.chargertype.charger.chargerstates[CHARGERSTATES.Done]) > 0:
-            return charger_state in self._hub.chargertype.charger.chargerstates[CHARGERSTATES.Done]
+        if len(self._hub.chargertype.charger.chargerstates[ChargeControllerStates.Done]) > 0:
+            return charger_state in self._hub.chargertype.charger.chargerstates[ChargeControllerStates.Done]
         return time.time() - self.latest_charger_start > self.done_timeout
 
     def update_latestchargerstart(self):
@@ -206,7 +206,7 @@ class ChargeControllerBase:
         """
         return (predicted_energy * 1000) > ((current_peak * 1000) * threshold_stop)
 
-    def _check_charger_states(self, input:Dict[CHARGERSTATES,List[str]]) -> Dict[CHARGERSTATES,List[str]]:
+    def _check_charger_states(self, input:Dict[ChargeControllerStates,List[str]]) -> Dict[ChargeControllerStates,List[str]]:
         if len(input) == 0:
             raise AssertionError
         return input
