@@ -1,7 +1,5 @@
 import logging
-from typing import Tuple
 from ...models.hourselection.cautionhourtype import CautionHourType
-from .hourselectionservice.hoursselection_helpers import HourSelectionHelpers as helpers
 from ...models.hourselection.hourselectionmodels import HourSelectionModel, HourSelectionOptions
 from ...models.hourselection.hourtypelist import HourTypeList
 from .hourselectionservice.hourselectionservice import HourSelectionService
@@ -21,12 +19,9 @@ class Hoursselection:
             options=HourSelectionOptions(
                 cautionhour_type=cautionhour_type, 
                 min_price=min_price,
-                absolute_top_price=HourSelectionOptions.set_absolute_top_price(
-                    absolute_top_price, 
-                    min_price
+                top_price= absolute_top_price
                     )
                 )
-            )
         self.model.validate()
         self.service = HourSelectionService(self.model, base_mock_hour)
     
@@ -71,7 +66,7 @@ class Hoursselection:
 
     @prices_tomorrow.setter
     def prices_tomorrow(self, val):
-        self.model.prices_tomorrow = helpers._convert_none_list(val)
+        self.model.prices_tomorrow = self.service.helpers.convert_none_list(val)
         if self.model.prices_tomorrow != []:
             self.service._preserve_interim = False
         self.update()
