@@ -1,23 +1,20 @@
-from ..free_charge import FreeChargePattern
-from ....models.locale.enums import CalendarPeriods
-from ..querytypes.const import (
-    QUERYTYPE_BASICMAX
-)
-
+from ....models.locale.enums.querytype import QueryType
+from ..time_pattern import TimePattern
+from ....models.locale.enums.calendar_periods import CalendarPeriods
 from ..locale_model import Locale_Type
 from dataclasses import dataclass
 
 @dataclass(frozen=True)
 class Default(Locale_Type):
-    observed_peak = QUERYTYPE_BASICMAX
-    charged_peak = QUERYTYPE_BASICMAX
+    observed_peak = QueryType.Max
+    charged_peak = QueryType.Max
 
 
 @dataclass(frozen=True)
 class NoPeak(Locale_Type):
-    observed_peak = QUERYTYPE_BASICMAX
-    charged_peak = QUERYTYPE_BASICMAX
-    free_charge_pattern = FreeChargePattern([
+    observed_peak = QueryType.Max
+    charged_peak = QueryType.Max
+    free_charge_pattern = TimePattern([
         {
             CalendarPeriods.Month: [1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12],
             CalendarPeriods.Weekday: [0, 1, 2, 3, 4, 5, 6],
