@@ -1,6 +1,7 @@
 from dataclasses import dataclass
 from datetime import datetime
 import logging
+import time
 
 _LOGGER = logging.getLogger(__name__)
 
@@ -21,7 +22,7 @@ class EnergyWeekly:
 
     def set_init_model(self):
         ret = {}
-        for i in range(0,6):
+        for i in range(0,7):
             ret[i] = Day(0,0)
         self.model = ret
 
@@ -35,15 +36,18 @@ class EnergyWeekly:
                 "total_charge": m.charge
             }
             ret[idx] = m_ret
+        return ret
 
     @property
     def average(self) -> float:
         sessions = sum([h.sessions for h in self.model.values()])
         charge = sum([h.charge for h in self.model.values()])
+        ret = 0.0
         try:
-            return round(charge/sessions,1)
+            ret = charge/sessions
         except:
-            return 0.0
+            _LOGGER.debug(f"Could not calculate average")
+        return round(ret,1)
         
     @property
     def total_sessions(self) -> int:
@@ -64,14 +68,21 @@ class EnergyWeekly:
     def unpack(self, incoming: dict) -> dict[int, Day]:
         if isinstance(incoming, dict) and len(incoming) > 0:
             model = {}
-            for idx, m in incoming.items():
-                m_ret = Day(m["sessions"], m["total_charge"])
-                model[idx] = m_ret
+            for i in range(0,7):
+                if i in incoming.keys():
+                    m_ret = Day(incoming[i]["sessions"], incoming[i]["total_charge"])    
+                else:
+                    m_ret = Day(0,0)
+                model[i] = m_ret
             self.model = model
+        else: 
+            return self.set_init_model()
 
-    def update(self, charge:float):
-        self.model[datetime.now().weekday()].charge += charge
-        self.model[datetime.now().weekday()].sessions += 1
+    def update(self, _charge:float, mock_time: int = None):
+        timer = mock_time if mock_time is not None else time.time()
+        if _charge > 0:
+            self.model[datetime.fromtimestamp(timer).weekday()].charge += _charge
+            self.model[datetime.fromtimestamp(timer).weekday()].sessions += 1
 
     def average_for_day(self, day: int) -> float:
         try:
@@ -90,8 +101,10 @@ class EnergyWeekly:
 # }
 
 # EXPORT_EXAMPLE = {0: {'sessions': 1, 'total_charge': 50}, 1: {'sessions': 4, 'total_charge': 50}, 2: {'sessions': 2, 'total_charge': 15}, 3: {'sessions': 3, 'total_charge': 20}, 4: {'sessions': 10, 'total_charge': 123}, 5: {'sessions': 0, 'total_charge': 0}, 6: {'sessions': 10, 'total_charge': 110}}
-
+# EXPORT_MISSING = {0: {'sessions': 1, 'total_charge': 50}, 2: {'sessions': 2, 'total_charge': 15}, 3: {'sessions': 3, 'total_charge': 20}, 4: {'sessions': 10, 'total_charge': 123}, 5: {'sessions': 0, 'total_charge': 0}, 6: {'sessions': 10, 'total_charge': 110}}
 # e = EnergyWeekly()
+# e.unpack(EXPORT_MISSING)
+# print(e.export)
 # print(e.model)
 # print(e.average)
 # print(e.average_for_day(0))
\ No newline at end of file
